# encoding: utf-8

module PuppetX
  module Eos
    ##
    # ModuleBase provides a base class for other modules to inherit from.
    # Methods common to all modules should be placed here.
    class ModuleBase
      attr_reader :api

      ##
      # Initialize instance of Module.  The Module class provides instance
      # methods to configure module related resources on the target device.
      #
      # @param [PuppetX::Eos::Eapi] api An instance of Eapi
      #
      # @return [PuppetX::Eos::ModuleBase]
      def initialize(api)
        @api = api
      end

      ##
      # running_configuration returns the current running configuration as a
      # string.  This method is intended to be used by subclasses.  The running
      # configuration is returned as a single string object to faciliate the
      # use of String#scan
      #
      # @api private
      #
      # @return [String]
      def running_configuration
        result = api.enable('show running-config', format: 'text')
        result.last['output']
      end
    end
  end
end
